<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-revisions?lang_cible=ar
// ** ne pas modifier le fichier **

return [

	// R
	'revisions_description' => 'متابعة التغييرات في العناصر التحريرية',
	'revisions_slogan' => 'متابعة التغييرات في العناصر التحريرية',
];
